@@ -27,7 +27,12 @@ def download(url, output_path):
     print('downloaded!')
     return
 
-@click.command(short_help=vignette1.renderText('DeepsmirUD'), context_settings=CONTEXT_SETTINGS)
+
+class HelpfulCmd(click.Command):
+    def format_help(self, ctx, formatter):
+        click.echo(vignette1.renderText('DeepsmirUD'))
+
+@click.command(cls=HelpfulCmd, context_settings=CONTEXT_SETTINGS)
 @click.option(
     '-m', '--method', default='LSTMCNN',
     help='''
